@@ -2,15 +2,16 @@ import json
 import time
 import pytest
 
-from toot import api
+from toot import api, cli
 from toot.exceptions import NotFoundError
 
 
 def test_delete(app, user, run):
     status = api.post_status(app, user, "foo").json()
 
-    out = run("delete", status["id"])
-    assert out == "✓ Status deleted"
+    result = run(cli.statuses.delete, status["id"])
+    assert result.exit_code == 0
+    assert result.stdout.strip() == "✓ Status deleted"
 
     with pytest.raises(NotFoundError):
         api.fetch_status(app, user, status["id"])
@@ -19,7 +20,10 @@ def test_delete(app, user, run):
 def test_delete_json(app, user, run):
     status = api.post_status(app, user, "foo").json()
 
-    out = run("delete", status["id"], "--json")
+    result = run(cli.statuses.delete, status["id"], "--json")
+    assert result.exit_code == 0
+
+    out = result.stdout
     result = json.loads(out)
     assert result["id"] == status["id"]
 
@@ -31,17 +35,19 @@ def test_favourite(app, user, run):
     status = api.post_status(app, user, "foo").json()
     assert not status["favourited"]
 
-    out = run("favourite", status["id"])
-    assert out == "✓ Status favourited"
+    result = run(cli.statuses.favourite, status["id"])
+    assert result.exit_code == 0
+    assert result.stdout.strip() == "✓ Status favourited"
 
     status = api.fetch_status(app, user, status["id"]).json()
     assert status["favourited"]
 
-    out = run("unfavourite", status["id"])
-    assert out == "✓ Status unfavourited"
+    result = run(cli.statuses.unfavourite, status["id"])
+    assert result.exit_code == 0
+    assert result.stdout.strip() == "✓ Status unfavourited"
 
     # A short delay is required before the server returns new data
-    time.sleep(0.1)
+    time.sleep(0.2)
 
     status = api.fetch_status(app, user, status["id"]).json()
     assert not status["favourited"]
@@ -51,15 +57,17 @@ def test_favourite_json(app, user, run):
     status = api.post_status(app, user, "foo").json()
     assert not status["favourited"]
 
-    out = run("favourite", status["id"], "--json")
-    result = json.loads(out)
+    result = run(cli.statuses.favourite, status["id"], "--json")
+    assert result.exit_code == 0
 
+    result = json.loads(result.stdout)
     assert result["id"] == status["id"]
     assert result["favourited"] is True
 
-    out = run("unfavourite", status["id"], "--json")
-    result = json.loads(out)
+    result = run(cli.statuses.unfavourite, status["id"], "--json")
+    assert result.exit_code == 0
 
+    result = json.loads(result.stdout)
     assert result["id"] == status["id"]
     assert result["favourited"] is False
 
@@ -68,17 +76,24 @@ def test_reblog(app, user, run):
     status = api.post_status(app, user, "foo").json()
     assert not status["reblogged"]
 
-    out = run("reblog", status["id"])
-    assert out == "✓ Status reblogged"
+    result = run(cli.statuses.reblogged_by, status["id"])
+    assert result.exit_code == 0
+    assert result.stdout.strip() == "This status is not reblogged by anyone"
+
+    result = run(cli.statuses.reblog, status["id"])
+    assert result.exit_code == 0
+    assert result.stdout.strip() == "✓ Status reblogged"
 
     status = api.fetch_status(app, user, status["id"]).json()
     assert status["reblogged"]
 
-    out = run("reblogged_by", status["id"])
-    assert user.username in out
+    result = run(cli.statuses.reblogged_by, status["id"])
+    assert result.exit_code == 0
+    assert user.username in result.stdout
 
-    out = run("unreblog", status["id"])
-    assert out == "✓ Status unreblogged"
+    result = run(cli.statuses.unreblog, status["id"])
+    assert result.exit_code == 0
+    assert result.stdout.strip() == "✓ Status unreblogged"
 
     status = api.fetch_status(app, user, status["id"]).json()
     assert not status["reblogged"]
@@ -88,19 +103,23 @@ def test_reblog_json(app, user, run):
     status = api.post_status(app, user, "foo").json()
     assert not status["reblogged"]
 
-    out = run("reblog", status["id"], "--json")
-    result = json.loads(out)
+    result = run(cli.statuses.reblog, status["id"], "--json")
+    assert result.exit_code == 0
 
+    result = json.loads(result.stdout)
     assert result["reblogged"] is True
     assert result["reblog"]["id"] == status["id"]
 
-    out = run("reblogged_by", status["id"], "--json")
-    [reblog] = json.loads(out)
+    result = run(cli.statuses.reblogged_by, status["id"], "--json")
+    assert result.exit_code == 0
+
+    [reblog] = json.loads(result.stdout)
     assert reblog["acct"] == user.username
 
-    out = run("unreblog", status["id"], "--json")
-    result = json.loads(out)
+    result = run(cli.statuses.unreblog, status["id"], "--json")
+    assert result.exit_code == 0
 
+    result = json.loads(result.stdout)
     assert result["reblogged"] is False
     assert result["reblog"] is None
 
@@ -109,14 +128,16 @@ def test_pin(app, user, run):
     status = api.post_status(app, user, "foo").json()
     assert not status["pinned"]
 
-    out = run("pin", status["id"])
-    assert out == "✓ Status pinned"
+    result = run(cli.statuses.pin, status["id"])
+    assert result.exit_code == 0
+    assert result.stdout.strip() == "✓ Status pinned"
 
     status = api.fetch_status(app, user, status["id"]).json()
     assert status["pinned"]
 
-    out = run("unpin", status["id"])
-    assert out == "✓ Status unpinned"
+    result = run(cli.statuses.unpin, status["id"])
+    assert result.exit_code == 0
+    assert result.stdout.strip() == "✓ Status unpinned"
 
     status = api.fetch_status(app, user, status["id"]).json()
     assert not status["pinned"]
@@ -126,15 +147,17 @@ def test_pin_json(app, user, run):
     status = api.post_status(app, user, "foo").json()
     assert not status["pinned"]
 
-    out = run("pin", status["id"], "--json")
-    result = json.loads(out)
+    result = run(cli.statuses.pin, status["id"], "--json")
+    assert result.exit_code == 0
 
+    result = json.loads(result.stdout)
     assert result["pinned"] is True
     assert result["id"] == status["id"]
 
-    out = run("unpin", status["id"], "--json")
-    result = json.loads(out)
+    result = run(cli.statuses.unpin, status["id"], "--json")
+    assert result.exit_code == 0
 
+    result = json.loads(result.stdout)
     assert result["pinned"] is False
     assert result["id"] == status["id"]
 
@@ -143,14 +166,16 @@ def test_bookmark(app, user, run):
     status = api.post_status(app, user, "foo").json()
     assert not status["bookmarked"]
 
-    out = run("bookmark", status["id"])
-    assert out == "✓ Status bookmarked"
+    result = run(cli.statuses.bookmark, status["id"])
+    assert result.exit_code == 0
+    assert result.stdout.strip() == "✓ Status bookmarked"
 
     status = api.fetch_status(app, user, status["id"]).json()
     assert status["bookmarked"]
 
-    out = run("unbookmark", status["id"])
-    assert out == "✓ Status unbookmarked"
+    result = run(cli.statuses.unbookmark, status["id"])
+    assert result.exit_code == 0
+    assert result.stdout.strip() == "✓ Status unbookmarked"
 
     status = api.fetch_status(app, user, status["id"]).json()
     assert not status["bookmarked"]
@@ -160,14 +185,16 @@ def test_bookmark_json(app, user, run):
     status = api.post_status(app, user, "foo").json()
     assert not status["bookmarked"]
 
-    out = run("bookmark", status["id"], "--json")
-    result = json.loads(out)
+    result = run(cli.statuses.bookmark, status["id"], "--json")
+    assert result.exit_code == 0
 
+    result = json.loads(result.stdout)
     assert result["id"] == status["id"]
     assert result["bookmarked"] is True
 
-    out = run("unbookmark", status["id"], "--json")
-    result = json.loads(out)
+    result = run(cli.statuses.unbookmark, status["id"], "--json")
+    assert result.exit_code == 0
 
+    result = json.loads(result.stdout)
     assert result["id"] == status["id"]
     assert result["bookmarked"] is False
